# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.datacatalog_v1beta1.proto import (
    datacatalog_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2,
)
from google.cloud.datacatalog_v1beta1.proto import (
    tags_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2,
)
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_iam__policy__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DataCatalogStub(object):
    """Data Catalog API service allows clients to discover, understand, and manage
  their data.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.SearchCatalog = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/SearchCatalog",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.SearchCatalogRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.SearchCatalogResponse.FromString,
        )
        self.CreateEntryGroup = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/CreateEntryGroup",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateEntryGroupRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.EntryGroup.FromString,
        )
        self.UpdateEntryGroup = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateEntryGroup",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateEntryGroupRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.EntryGroup.FromString,
        )
        self.GetEntryGroup = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/GetEntryGroup",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetEntryGroupRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.EntryGroup.FromString,
        )
        self.DeleteEntryGroup = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/DeleteEntryGroup",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteEntryGroupRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ListEntryGroups = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/ListEntryGroups",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListEntryGroupsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListEntryGroupsResponse.FromString,
        )
        self.CreateEntry = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/CreateEntry",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateEntryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.FromString,
        )
        self.UpdateEntry = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateEntry",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateEntryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.FromString,
        )
        self.DeleteEntry = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/DeleteEntry",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteEntryRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.GetEntry = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/GetEntry",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetEntryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.FromString,
        )
        self.LookupEntry = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/LookupEntry",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.LookupEntryRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.FromString,
        )
        self.ListEntries = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/ListEntries",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListEntriesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListEntriesResponse.FromString,
        )
        self.CreateTagTemplate = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/CreateTagTemplate",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.FromString,
        )
        self.GetTagTemplate = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/GetTagTemplate",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetTagTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.FromString,
        )
        self.UpdateTagTemplate = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateTagTemplate",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagTemplateRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.FromString,
        )
        self.DeleteTagTemplate = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/DeleteTagTemplate",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagTemplateRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateTagTemplateField = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/CreateTagTemplateField",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagTemplateFieldRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.FromString,
        )
        self.UpdateTagTemplateField = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateTagTemplateField",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagTemplateFieldRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.FromString,
        )
        self.RenameTagTemplateField = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/RenameTagTemplateField",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.RenameTagTemplateFieldRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.FromString,
        )
        self.DeleteTagTemplateField = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/DeleteTagTemplateField",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagTemplateFieldRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateTag = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/CreateTag",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.Tag.FromString,
        )
        self.UpdateTag = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/UpdateTag",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.Tag.FromString,
        )
        self.DeleteTag = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/DeleteTag",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ListTags = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/ListTags",
            request_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListTagsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListTagsResponse.FromString,
        )
        self.SetIamPolicy = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/SetIamPolicy",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.SetIamPolicyRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.FromString,
        )
        self.GetIamPolicy = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/GetIamPolicy",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.GetIamPolicyRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.FromString,
        )
        self.TestIamPermissions = channel.unary_unary(
            "/google.cloud.datacatalog.v1beta1.DataCatalog/TestIamPermissions",
            request_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsRequest.SerializeToString,
            response_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsResponse.FromString,
        )


class DataCatalogServicer(object):
    """Data Catalog API service allows clients to discover, understand, and manage
  their data.
  """

    def SearchCatalog(self, request, context):
        """Searches Data Catalog for multiple resources like entries, tags that
    match a query.

    This is a custom method
    (https://cloud.google.com/apis/design/custom_methods) and does not return
    the complete resource, only the resource identifier and high level
    fields. Clients can subsequentally call `Get` methods.

    Note that Data Catalog search queries do not guarantee full recall. Query
    results that match your query may not be returned, even in subsequent
    result pages. Also note that results returned (and not returned) can vary
    across repeated search queries.

    See [Data Catalog Search
    Syntax](https://cloud.google.com/data-catalog/docs/how-to/search-reference)
    for more information.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateEntryGroup(self, request, context):
        """A maximum of 10,000 entry groups may be created per organization across all
    locations.

    Users should enable the Data Catalog API in the project identified by
    the `parent` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateEntryGroup(self, request, context):
        """Updates an EntryGroup. The user should enable the Data Catalog API in the
    project identified by the `entry_group.name` parameter (see [Data Catalog
    Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntryGroup(self, request, context):
        """Gets an EntryGroup.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteEntryGroup(self, request, context):
        """Deletes an EntryGroup. Only entry groups that do not contain entries can be
    deleted. Users should enable the Data Catalog API in the project
    identified by the `name` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListEntryGroups(self, request, context):
        """Lists entry groups.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateEntry(self, request, context):
        """Creates an entry. Only entries of 'FILESET' type or user-specified type can
    be created.

    Users should enable the Data Catalog API in the project identified by
    the `parent` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).

    A maximum of 100,000 entries may be created per entry group.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateEntry(self, request, context):
        """Updates an existing entry.
    Users should enable the Data Catalog API in the project identified by
    the `entry.name` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteEntry(self, request, context):
        """Deletes an existing entry. Only entries created through
    [CreateEntry][google.cloud.datacatalog.v1beta1.DataCatalog.CreateEntry]
    method can be deleted.
    Users should enable the Data Catalog API in the project identified by
    the `name` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetEntry(self, request, context):
        """Gets an entry.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def LookupEntry(self, request, context):
        """Get an entry by target resource name. This method allows clients to use
    the resource name from the source Google Cloud Platform service to get the
    Data Catalog Entry.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListEntries(self, request, context):
        """Lists entries.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateTagTemplate(self, request, context):
        """Creates a tag template. The user should enable the Data Catalog API in
    the project identified by the `parent` parameter (see [Data Catalog
    Resource
    Project](https://cloud.google.com/data-catalog/docs/concepts/resource-project)
    for more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTagTemplate(self, request, context):
        """Gets a tag template.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTagTemplate(self, request, context):
        """Updates a tag template. This method cannot be used to update the fields of
    a template. The tag template fields are represented as separate resources
    and should be updated using their own create/update/delete methods.
    Users should enable the Data Catalog API in the project identified by
    the `tag_template.name` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTagTemplate(self, request, context):
        """Deletes a tag template and all tags using the template.
    Users should enable the Data Catalog API in the project identified by
    the `name` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateTagTemplateField(self, request, context):
        """Creates a field in a tag template. The user should enable the Data Catalog
    API in the project identified by the `parent` parameter (see
    [Data Catalog Resource
    Project](https://cloud.google.com/data-catalog/docs/concepts/resource-project)
    for more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTagTemplateField(self, request, context):
        """Updates a field in a tag template. This method cannot be used to update the
    field type. Users should enable the Data Catalog API in the project
    identified by the `name` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RenameTagTemplateField(self, request, context):
        """Renames a field in a tag template. The user should enable the Data Catalog
    API in the project identified by the `name` parameter (see [Data Catalog
    Resource
    Project](https://cloud.google.com/data-catalog/docs/concepts/resource-project)
    for more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTagTemplateField(self, request, context):
        """Deletes a field in a tag template and all uses of that field.
    Users should enable the Data Catalog API in the project identified by
    the `name` parameter (see [Data Catalog Resource Project]
    (https://cloud.google.com/data-catalog/docs/concepts/resource-project) for
    more information).
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateTag(self, request, context):
        """Creates a tag on an [Entry][google.cloud.datacatalog.v1beta1.Entry].
    Note: The project identified by the `parent` parameter for the
    [tag](https://cloud.google.com/data-catalog/docs/reference/rest/v1beta1/projects.locations.entryGroups.entries.tags/create#path-parameters)
    and the
    [tag
    template](https://cloud.google.com/data-catalog/docs/reference/rest/v1beta1/projects.locations.tagTemplates/create#path-parameters)
    used to create the tag must be from the same organization.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTag(self, request, context):
        """Updates an existing tag.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTag(self, request, context):
        """Deletes a tag.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListTags(self, request, context):
        """Lists the tags on an [Entry][google.cloud.datacatalog.v1beta1.Entry].
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SetIamPolicy(self, request, context):
        """Sets the access control policy for a resource. Replaces any existing
    policy.
    Supported resources are:
    - Tag templates.
    - Entries.
    - Entry groups.
    Note, this method cannot be used to manage policies for BigQuery, Pub/Sub
    and any external Google Cloud Platform resources synced to Data Catalog.

    Callers must have following Google IAM permission
    - `datacatalog.tagTemplates.setIamPolicy` to set policies on tag
    templates.
    - `datacatalog.entries.setIamPolicy` to set policies on entries.
    - `datacatalog.entryGroups.setIamPolicy` to set policies on entry groups.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetIamPolicy(self, request, context):
        """Gets the access control policy for a resource. A `NOT_FOUND` error
    is returned if the resource does not exist. An empty policy is returned
    if the resource exists but does not have a policy set on it.

    Supported resources are:
    - Tag templates.
    - Entries.
    - Entry groups.
    Note, this method cannot be used to manage policies for BigQuery, Pub/Sub
    and any external Google Cloud Platform resources synced to Data Catalog.

    Callers must have following Google IAM permission
    - `datacatalog.tagTemplates.getIamPolicy` to get policies on tag
    templates.
    - `datacatalog.entries.getIamPolicy` to get policies on entries.
    - `datacatalog.entryGroups.getIamPolicy` to get policies on entry groups.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def TestIamPermissions(self, request, context):
        """Returns the caller's permissions on a resource.
    If the resource does not exist, an empty set of permissions is returned
    (We don't return a `NOT_FOUND` error).

    Supported resources are:
    - Tag templates.
    - Entries.
    - Entry groups.
    Note, this method cannot be used to manage policies for BigQuery, Pub/Sub
    and any external Google Cloud Platform resources synced to Data Catalog.

    A caller is not required to have Google IAM permission to make this
    request.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DataCatalogServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "SearchCatalog": grpc.unary_unary_rpc_method_handler(
            servicer.SearchCatalog,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.SearchCatalogRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.SearchCatalogResponse.SerializeToString,
        ),
        "CreateEntryGroup": grpc.unary_unary_rpc_method_handler(
            servicer.CreateEntryGroup,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateEntryGroupRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.EntryGroup.SerializeToString,
        ),
        "UpdateEntryGroup": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateEntryGroup,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateEntryGroupRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.EntryGroup.SerializeToString,
        ),
        "GetEntryGroup": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntryGroup,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetEntryGroupRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.EntryGroup.SerializeToString,
        ),
        "DeleteEntryGroup": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteEntryGroup,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteEntryGroupRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ListEntryGroups": grpc.unary_unary_rpc_method_handler(
            servicer.ListEntryGroups,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListEntryGroupsRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListEntryGroupsResponse.SerializeToString,
        ),
        "CreateEntry": grpc.unary_unary_rpc_method_handler(
            servicer.CreateEntry,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateEntryRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.SerializeToString,
        ),
        "UpdateEntry": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateEntry,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateEntryRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.SerializeToString,
        ),
        "DeleteEntry": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteEntry,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteEntryRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "GetEntry": grpc.unary_unary_rpc_method_handler(
            servicer.GetEntry,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetEntryRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.SerializeToString,
        ),
        "LookupEntry": grpc.unary_unary_rpc_method_handler(
            servicer.LookupEntry,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.LookupEntryRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.Entry.SerializeToString,
        ),
        "ListEntries": grpc.unary_unary_rpc_method_handler(
            servicer.ListEntries,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListEntriesRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListEntriesResponse.SerializeToString,
        ),
        "CreateTagTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTagTemplate,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.SerializeToString,
        ),
        "GetTagTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.GetTagTemplate,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.GetTagTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.SerializeToString,
        ),
        "UpdateTagTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTagTemplate,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagTemplateRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplate.SerializeToString,
        ),
        "DeleteTagTemplate": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTagTemplate,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagTemplateRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateTagTemplateField": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTagTemplateField,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagTemplateFieldRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.SerializeToString,
        ),
        "UpdateTagTemplateField": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTagTemplateField,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagTemplateFieldRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.SerializeToString,
        ),
        "RenameTagTemplateField": grpc.unary_unary_rpc_method_handler(
            servicer.RenameTagTemplateField,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.RenameTagTemplateFieldRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.TagTemplateField.SerializeToString,
        ),
        "DeleteTagTemplateField": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTagTemplateField,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagTemplateFieldRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateTag": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTag,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.CreateTagRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.Tag.SerializeToString,
        ),
        "UpdateTag": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTag,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.UpdateTagRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_tags__pb2.Tag.SerializeToString,
        ),
        "DeleteTag": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTag,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.DeleteTagRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ListTags": grpc.unary_unary_rpc_method_handler(
            servicer.ListTags,
            request_deserializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListTagsRequest.FromString,
            response_serializer=google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_datacatalog__pb2.ListTagsResponse.SerializeToString,
        ),
        "SetIamPolicy": grpc.unary_unary_rpc_method_handler(
            servicer.SetIamPolicy,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.SetIamPolicyRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.SerializeToString,
        ),
        "GetIamPolicy": grpc.unary_unary_rpc_method_handler(
            servicer.GetIamPolicy,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.GetIamPolicyRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_policy__pb2.Policy.SerializeToString,
        ),
        "TestIamPermissions": grpc.unary_unary_rpc_method_handler(
            servicer.TestIamPermissions,
            request_deserializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsRequest.FromString,
            response_serializer=google_dot_iam_dot_v1_dot_iam__policy__pb2.TestIamPermissionsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.datacatalog.v1beta1.DataCatalog", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1beta1/proto/tags.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1beta1/proto/tags.proto",
    package="google.cloud.datacatalog.v1beta1",
    syntax="proto3",
    serialized_options=b"\n$com.google.cloud.datacatalog.v1beta1P\001ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\370\001\001\252\002 Google.Cloud.DataCatalog.V1Beta1\312\002 Google\\Cloud\\DataCatalog\\V1beta1\352\002#Google::Cloud::DataCatalog::V1beta1",
    serialized_pb=b'\n1google/cloud/datacatalog_v1beta1/proto/tags.proto\x12 google.cloud.datacatalog.v1beta1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\x90\x03\n\x03Tag\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\x08template\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12"\n\x15template_display_name\x18\x05 \x01(\tB\x03\xe0\x41\x03\x12\x10\n\x06\x63olumn\x18\x04 \x01(\tH\x00\x12\x46\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x31.google.cloud.datacatalog.v1beta1.Tag.FieldsEntryB\x03\xe0\x41\x02\x1aY\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.google.cloud.datacatalog.v1beta1.TagField:\x02\x38\x01:\x81\x01\xea\x41~\n\x1e\x64\x61tacatalog.googleapis.com/Tag\x12\\projects/{project}/locations/{location}/entryGroups/{entry_group}/entries/{entry}/tags/{tag}B\x07\n\x05scope"\xad\x02\n\x08TagField\x12\x19\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x16\n\x0c\x64ouble_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12\x35\n\x0ftimestamp_value\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12J\n\nenum_value\x18\x06 \x01(\x0b\x32\x34.google.cloud.datacatalog.v1beta1.TagField.EnumValueH\x00\x12\x12\n\x05order\x18\x07 \x01(\x05\x42\x03\xe0\x41\x03\x1a!\n\tEnumValue\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x06\n\x04kind"\xd6\x02\n\x0bTagTemplate\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12N\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x39.google.cloud.datacatalog.v1beta1.TagTemplate.FieldsEntryB\x03\xe0\x41\x02\x1a\x61\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.google.cloud.datacatalog.v1beta1.TagTemplateField:\x02\x38\x01:p\xea\x41m\n&datacatalog.googleapis.com/TagTemplate\x12\x43projects/{project}/locations/{location}/tagTemplates/{tag_template}"\xa7\x02\n\x10TagTemplateField\x12\x11\n\x04name\x18\x06 \x01(\tB\x03\xe0\x41\x03\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12>\n\x04type\x18\x02 \x01(\x0b\x32+.google.cloud.datacatalog.v1beta1.FieldTypeB\x03\xe0\x41\x02\x12\x13\n\x0bis_required\x18\x03 \x01(\x08\x12\r\n\x05order\x18\x05 \x01(\x05:\x85\x01\xea\x41\x81\x01\n+datacatalog.googleapis.com/TagTemplateField\x12Rprojects/{project}/locations/{location}/tagTemplates/{tag_template}/fields/{field}"\xa7\x03\n\tFieldType\x12S\n\x0eprimitive_type\x18\x01 \x01(\x0e\x32\x39.google.cloud.datacatalog.v1beta1.FieldType.PrimitiveTypeH\x00\x12I\n\tenum_type\x18\x02 \x01(\x0b\x32\x34.google.cloud.datacatalog.v1beta1.FieldType.EnumTypeH\x00\x1a\x8a\x01\n\x08\x45numType\x12V\n\x0e\x61llowed_values\x18\x01 \x03(\x0b\x32>.google.cloud.datacatalog.v1beta1.FieldType.EnumType.EnumValue\x1a&\n\tEnumValue\x12\x19\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x03\xe0\x41\x02"`\n\rPrimitiveType\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x44OUBLE\x10\x01\x12\n\n\x06STRING\x10\x02\x12\x08\n\x04\x42OOL\x10\x03\x12\r\n\tTIMESTAMP\x10\x04\x42\x0b\n\ttype_declB\xe4\x01\n$com.google.cloud.datacatalog.v1beta1P\x01ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\xf8\x01\x01\xaa\x02 Google.Cloud.DataCatalog.V1Beta1\xca\x02 Google\\Cloud\\DataCatalog\\V1beta1\xea\x02#Google::Cloud::DataCatalog::V1beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
    ],
)


_FIELDTYPE_PRIMITIVETYPE = _descriptor.EnumDescriptor(
    name="PrimitiveType",
    full_name="google.cloud.datacatalog.v1beta1.FieldType.PrimitiveType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="PRIMITIVE_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="DOUBLE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="STRING", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="BOOL", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TIMESTAMP", index=4, number=4, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1845,
    serialized_end=1941,
)
_sym_db.RegisterEnumDescriptor(_FIELDTYPE_PRIMITIVETYPE)


_TAG_FIELDSENTRY = _descriptor.Descriptor(
    name="FieldsEntry",
    full_name="google.cloud.datacatalog.v1beta1.Tag.FieldsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.datacatalog.v1beta1.Tag.FieldsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.datacatalog.v1beta1.Tag.FieldsEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=351,
    serialized_end=440,
)

_TAG = _descriptor.Descriptor(
    name="Tag",
    full_name="google.cloud.datacatalog.v1beta1.Tag",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.Tag.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="template",
            full_name="google.cloud.datacatalog.v1beta1.Tag.template",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="template_display_name",
            full_name="google.cloud.datacatalog.v1beta1.Tag.template_display_name",
            index=2,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="column",
            full_name="google.cloud.datacatalog.v1beta1.Tag.column",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="fields",
            full_name="google.cloud.datacatalog.v1beta1.Tag.fields",
            index=4,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_TAG_FIELDSENTRY],
    enum_types=[],
    serialized_options=b"\352A~\n\036datacatalog.googleapis.com/Tag\022\\projects/{project}/locations/{location}/entryGroups/{entry_group}/entries/{entry}/tags/{tag}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="scope",
            full_name="google.cloud.datacatalog.v1beta1.Tag.scope",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=181,
    serialized_end=581,
)


_TAGFIELD_ENUMVALUE = _descriptor.Descriptor(
    name="EnumValue",
    full_name="google.cloud.datacatalog.v1beta1.TagField.EnumValue",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.TagField.EnumValue.display_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=844,
    serialized_end=877,
)

_TAGFIELD = _descriptor.Descriptor(
    name="TagField",
    full_name="google.cloud.datacatalog.v1beta1.TagField",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.TagField.display_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="double_value",
            full_name="google.cloud.datacatalog.v1beta1.TagField.double_value",
            index=1,
            number=2,
            type=1,
            cpp_type=5,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="string_value",
            full_name="google.cloud.datacatalog.v1beta1.TagField.string_value",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="bool_value",
            full_name="google.cloud.datacatalog.v1beta1.TagField.bool_value",
            index=3,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="timestamp_value",
            full_name="google.cloud.datacatalog.v1beta1.TagField.timestamp_value",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="enum_value",
            full_name="google.cloud.datacatalog.v1beta1.TagField.enum_value",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="order",
            full_name="google.cloud.datacatalog.v1beta1.TagField.order",
            index=6,
            number=7,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_TAGFIELD_ENUMVALUE],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="kind",
            full_name="google.cloud.datacatalog.v1beta1.TagField.kind",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=584,
    serialized_end=885,
)


_TAGTEMPLATE_FIELDSENTRY = _descriptor.Descriptor(
    name="FieldsEntry",
    full_name="google.cloud.datacatalog.v1beta1.TagTemplate.FieldsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplate.FieldsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplate.FieldsEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1019,
    serialized_end=1116,
)

_TAGTEMPLATE = _descriptor.Descriptor(
    name="TagTemplate",
    full_name="google.cloud.datacatalog.v1beta1.TagTemplate",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplate.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplate.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="fields",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplate.fields",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_TAGTEMPLATE_FIELDSENTRY],
    enum_types=[],
    serialized_options=b"\352Am\n&datacatalog.googleapis.com/TagTemplate\022Cprojects/{project}/locations/{location}/tagTemplates/{tag_template}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=888,
    serialized_end=1230,
)


_TAGTEMPLATEFIELD = _descriptor.Descriptor(
    name="TagTemplateField",
    full_name="google.cloud.datacatalog.v1beta1.TagTemplateField",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplateField.name",
            index=0,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplateField.display_name",
            index=1,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplateField.type",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="is_required",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplateField.is_required",
            index=3,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="order",
            full_name="google.cloud.datacatalog.v1beta1.TagTemplateField.order",
            index=4,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A\201\001\n+datacatalog.googleapis.com/TagTemplateField\022Rprojects/{project}/locations/{location}/tagTemplates/{tag_template}/fields/{field}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1233,
    serialized_end=1528,
)


_FIELDTYPE_ENUMTYPE_ENUMVALUE = _descriptor.Descriptor(
    name="EnumValue",
    full_name="google.cloud.datacatalog.v1beta1.FieldType.EnumType.EnumValue",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.FieldType.EnumType.EnumValue.display_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1805,
    serialized_end=1843,
)

_FIELDTYPE_ENUMTYPE = _descriptor.Descriptor(
    name="EnumType",
    full_name="google.cloud.datacatalog.v1beta1.FieldType.EnumType",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="allowed_values",
            full_name="google.cloud.datacatalog.v1beta1.FieldType.EnumType.allowed_values",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_FIELDTYPE_ENUMTYPE_ENUMVALUE],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1705,
    serialized_end=1843,
)

_FIELDTYPE = _descriptor.Descriptor(
    name="FieldType",
    full_name="google.cloud.datacatalog.v1beta1.FieldType",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="primitive_type",
            full_name="google.cloud.datacatalog.v1beta1.FieldType.primitive_type",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="enum_type",
            full_name="google.cloud.datacatalog.v1beta1.FieldType.enum_type",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_FIELDTYPE_ENUMTYPE],
    enum_types=[_FIELDTYPE_PRIMITIVETYPE],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="type_decl",
            full_name="google.cloud.datacatalog.v1beta1.FieldType.type_decl",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1531,
    serialized_end=1954,
)

_TAG_FIELDSENTRY.fields_by_name["value"].message_type = _TAGFIELD
_TAG_FIELDSENTRY.containing_type = _TAG
_TAG.fields_by_name["fields"].message_type = _TAG_FIELDSENTRY
_TAG.oneofs_by_name["scope"].fields.append(_TAG.fields_by_name["column"])
_TAG.fields_by_name["column"].containing_oneof = _TAG.oneofs_by_name["scope"]
_TAGFIELD_ENUMVALUE.containing_type = _TAGFIELD
_TAGFIELD.fields_by_name[
    "timestamp_value"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TAGFIELD.fields_by_name["enum_value"].message_type = _TAGFIELD_ENUMVALUE
_TAGFIELD.oneofs_by_name["kind"].fields.append(_TAGFIELD.fields_by_name["double_value"])
_TAGFIELD.fields_by_name["double_value"].containing_oneof = _TAGFIELD.oneofs_by_name[
    "kind"
]
_TAGFIELD.oneofs_by_name["kind"].fields.append(_TAGFIELD.fields_by_name["string_value"])
_TAGFIELD.fields_by_name["string_value"].containing_oneof = _TAGFIELD.oneofs_by_name[
    "kind"
]
_TAGFIELD.oneofs_by_name["kind"].fields.append(_TAGFIELD.fields_by_name["bool_value"])
_TAGFIELD.fields_by_name["bool_value"].containing_oneof = _TAGFIELD.oneofs_by_name[
    "kind"
]
_TAGFIELD.oneofs_by_name["kind"].fields.append(
    _TAGFIELD.fields_by_name["timestamp_value"]
)
_TAGFIELD.fields_by_name["timestamp_value"].containing_oneof = _TAGFIELD.oneofs_by_name[
    "kind"
]
_TAGFIELD.oneofs_by_name["kind"].fields.append(_TAGFIELD.fields_by_name["enum_value"])
_TAGFIELD.fields_by_name["enum_value"].containing_oneof = _TAGFIELD.oneofs_by_name[
    "kind"
]
_TAGTEMPLATE_FIELDSENTRY.fields_by_name["value"].message_type = _TAGTEMPLATEFIELD
_TAGTEMPLATE_FIELDSENTRY.containing_type = _TAGTEMPLATE
_TAGTEMPLATE.fields_by_name["fields"].message_type = _TAGTEMPLATE_FIELDSENTRY
_TAGTEMPLATEFIELD.fields_by_name["type"].message_type = _FIELDTYPE
_FIELDTYPE_ENUMTYPE_ENUMVALUE.containing_type = _FIELDTYPE_ENUMTYPE
_FIELDTYPE_ENUMTYPE.fields_by_name[
    "allowed_values"
].message_type = _FIELDTYPE_ENUMTYPE_ENUMVALUE
_FIELDTYPE_ENUMTYPE.containing_type = _FIELDTYPE
_FIELDTYPE.fields_by_name["primitive_type"].enum_type = _FIELDTYPE_PRIMITIVETYPE
_FIELDTYPE.fields_by_name["enum_type"].message_type = _FIELDTYPE_ENUMTYPE
_FIELDTYPE_PRIMITIVETYPE.containing_type = _FIELDTYPE
_FIELDTYPE.oneofs_by_name["type_decl"].fields.append(
    _FIELDTYPE.fields_by_name["primitive_type"]
)
_FIELDTYPE.fields_by_name[
    "primitive_type"
].containing_oneof = _FIELDTYPE.oneofs_by_name["type_decl"]
_FIELDTYPE.oneofs_by_name["type_decl"].fields.append(
    _FIELDTYPE.fields_by_name["enum_type"]
)
_FIELDTYPE.fields_by_name["enum_type"].containing_oneof = _FIELDTYPE.oneofs_by_name[
    "type_decl"
]
DESCRIPTOR.message_types_by_name["Tag"] = _TAG
DESCRIPTOR.message_types_by_name["TagField"] = _TAGFIELD
DESCRIPTOR.message_types_by_name["TagTemplate"] = _TAGTEMPLATE
DESCRIPTOR.message_types_by_name["TagTemplateField"] = _TAGTEMPLATEFIELD
DESCRIPTOR.message_types_by_name["FieldType"] = _FIELDTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tag = _reflection.GeneratedProtocolMessageType(
    "Tag",
    (_message.Message,),
    {
        "FieldsEntry": _reflection.GeneratedProtocolMessageType(
            "FieldsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _TAG_FIELDSENTRY,
                "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.Tag.FieldsEntry)
            },
        ),
        "DESCRIPTOR": _TAG,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2",
        "__doc__": """Tags are used to attach custom metadata to Data Catalog
  resources. Tags conform to the specifications within their tag template.
  
  See `Data Catalog
  IAM <https://cloud.google.com/data-catalog/docs/concepts/iam>`__ for
  information on the permissions needed to create or view tags.
  
  
  Attributes:
      name:
          The resource name of the tag in URL format. Example:  -  proje
          cts/{project_id}/locations/{location}/entrygroups/{entry_group
          _id}/entries/{entry_id}/tags/{tag_id}  where ``tag_id`` is a
          system-generated identifier. Note that this Tag may not
          actually be stored in the location in this name.
      template:
          Required. The resource name of the tag template that this tag
          uses. Example:  -  projects/{project_id}/locations/{location}/
          tagTemplates/{tag_template_id}  This field cannot be modified
          after creation.
      template_display_name:
          Output only. The display name of the tag template.
      scope:
          The scope within the parent resource that this tag is attached
          to. If not provided, the tag is attached to the parent
          resource itself. Deleting the scope from the parent resource
          will delete all tags attached to that scope. These fields
          cannot be updated after creation.
      column:
          Resources like Entry can have schemas associated with them.
          This scope allows users to attach tags to an individual column
          based on that schema.  For attaching a tag to a nested column,
          use ``.`` to separate the column names. Example:  -
          ``outer_column.inner_column``
      fields:
          Required. This maps the ID of a tag field to the value of and
          additional information about that field. Valid field IDs are
          defined by the tag’s template. A tag must have at least 1
          field and at most 500 fields.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.Tag)
    },
)
_sym_db.RegisterMessage(Tag)
_sym_db.RegisterMessage(Tag.FieldsEntry)

TagField = _reflection.GeneratedProtocolMessageType(
    "TagField",
    (_message.Message,),
    {
        "EnumValue": _reflection.GeneratedProtocolMessageType(
            "EnumValue",
            (_message.Message,),
            {
                "DESCRIPTOR": _TAGFIELD_ENUMVALUE,
                "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2",
                "__doc__": """Holds an enum value.
    
    
    Attributes:
        display_name:
            The display name of the enum value.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.TagField.EnumValue)
            },
        ),
        "DESCRIPTOR": _TAGFIELD,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2",
        "__doc__": """Contains the value and supporting information for a field
  within a [Tag][google.cloud.datacatalog.v1beta1.Tag].
  
  
  Attributes:
      display_name:
          Output only. The display name of this field.
      kind:
          Required. The value of this field.
      double_value:
          Holds the value for a tag field with double type.
      string_value:
          Holds the value for a tag field with string type.
      bool_value:
          Holds the value for a tag field with boolean type.
      timestamp_value:
          Holds the value for a tag field with timestamp type.
      enum_value:
          Holds the value for a tag field with enum type. This value
          must be one of the allowed values in the definition of this
          enum.
      order:
          Output only. The order of this field with respect to other
          fields in this tag. It can be set in [Tag][google.cloud.dataca
          talog.v1beta1.TagTemplateField.order]. For example, a higher
          value can indicate a more important field. The value can be
          negative. Multiple fields can have the same order, and field
          orders within a tag do not have to be sequential.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.TagField)
    },
)
_sym_db.RegisterMessage(TagField)
_sym_db.RegisterMessage(TagField.EnumValue)

TagTemplate = _reflection.GeneratedProtocolMessageType(
    "TagTemplate",
    (_message.Message,),
    {
        "FieldsEntry": _reflection.GeneratedProtocolMessageType(
            "FieldsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _TAGTEMPLATE_FIELDSENTRY,
                "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.TagTemplate.FieldsEntry)
            },
        ),
        "DESCRIPTOR": _TAGTEMPLATE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2",
        "__doc__": """A tag template defines a tag, which can have one or more
  typed fields. The template is used to create and attach the tag to GCP
  resources. `Tag template
  roles <https://cloud.google.com/iam/docs/understanding-roles#data-catalog-roles>`__
  provide permissions to create, edit, and use the template. See, for
  example, the `TagTemplate
  User <https://cloud.google.com/data-catalog/docs/how-to/template-user>`__
  role, which includes permission to use the tag template to tag
  resources.
  
  
  Attributes:
      name:
          The resource name of the tag template in URL format. Example:
          -  projects/{project_id}/locations/{location}/tagTemplates/{ta
          g_template_id}  Note that this TagTemplate and its child
          resources may not actually be stored in the location in this
          name.
      display_name:
          The display name for this template. Defaults to an empty
          string.
      fields:
          Required. Map of tag template field IDs to the settings for
          the field. This map is an exhaustive list of the allowed
          fields. This map must contain at least one field and at most
          500 fields.  The keys to this map are tag template field IDs.
          Field IDs can contain letters (both uppercase and lowercase),
          numbers (0-9) and underscores (_). Field IDs must be at least
          1 character long and at most 64 characters long. Field IDs
          must start with a letter or underscore.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.TagTemplate)
    },
)
_sym_db.RegisterMessage(TagTemplate)
_sym_db.RegisterMessage(TagTemplate.FieldsEntry)

TagTemplateField = _reflection.GeneratedProtocolMessageType(
    "TagTemplateField",
    (_message.Message,),
    {
        "DESCRIPTOR": _TAGTEMPLATEFIELD,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2",
        "__doc__": """The template for an individual field within a tag
  template.
  
  
  Attributes:
      name:
          Output only. The resource name of the tag template field in
          URL format. Example:  -  projects/{project_id}/locations/{loca
          tion}/tagTemplates/{tag_template}/fields/{field}  Note that
          this TagTemplateField may not actually be stored in the
          location in this name.
      display_name:
          The display name for this field. Defaults to an empty string.
      type:
          Required. The type of value this tag field can contain.
      is_required:
          Whether this is a required field. Defaults to false.
      order:
          The order of this field with respect to other fields in this
          tag template. A higher value indicates a more important field.
          The value can be negative. Multiple fields can have the same
          order, and field orders within a tag do not have to be
          sequential.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.TagTemplateField)
    },
)
_sym_db.RegisterMessage(TagTemplateField)

FieldType = _reflection.GeneratedProtocolMessageType(
    "FieldType",
    (_message.Message,),
    {
        "EnumType": _reflection.GeneratedProtocolMessageType(
            "EnumType",
            (_message.Message,),
            {
                "EnumValue": _reflection.GeneratedProtocolMessageType(
                    "EnumValue",
                    (_message.Message,),
                    {
                        "DESCRIPTOR": _FIELDTYPE_ENUMTYPE_ENUMVALUE,
                        "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2",
                        "__doc__": """
    Attributes:
          display_name:
              Required. The display name of the enum value. Must not be an
              empty string.
      """,
                        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.FieldType.EnumType.EnumValue)
                    },
                ),
                "DESCRIPTOR": _FIELDTYPE_ENUMTYPE,
                "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2",
                "__doc__": """
    Attributes:
        allowed_values:
            Required on create; optional on update. The set of allowed
            values for this enum. This set must not be empty, the display
            names of the values in this set must not be empty and the
            display names of the values must be case-insensitively unique
            within this set. Currently, enum values can only be added to
            the list of allowed values. Deletion and renaming of enum
            values are not supported. Can have up to 500 allowed values.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.FieldType.EnumType)
            },
        ),
        "DESCRIPTOR": _FIELDTYPE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.tags_pb2",
        "__doc__": """
    Attributes:
      type_decl:
          Required.
      primitive_type:
          Represents primitive types - string, bool etc.
      enum_type:
          Represents an enum type.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.FieldType)
    },
)
_sym_db.RegisterMessage(FieldType)
_sym_db.RegisterMessage(FieldType.EnumType)
_sym_db.RegisterMessage(FieldType.EnumType.EnumValue)


DESCRIPTOR._options = None
_TAG_FIELDSENTRY._options = None
_TAG.fields_by_name["template"]._options = None
_TAG.fields_by_name["template_display_name"]._options = None
_TAG.fields_by_name["fields"]._options = None
_TAG._options = None
_TAGFIELD.fields_by_name["display_name"]._options = None
_TAGFIELD.fields_by_name["order"]._options = None
_TAGTEMPLATE_FIELDSENTRY._options = None
_TAGTEMPLATE.fields_by_name["fields"]._options = None
_TAGTEMPLATE._options = None
_TAGTEMPLATEFIELD.fields_by_name["name"]._options = None
_TAGTEMPLATEFIELD.fields_by_name["type"]._options = None
_TAGTEMPLATEFIELD._options = None
_FIELDTYPE_ENUMTYPE_ENUMVALUE.fields_by_name["display_name"]._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1beta1/proto/policytagmanagerserialization.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.datacatalog_v1beta1.proto import (
    policytagmanager_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanager__pb2,
)
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1beta1/proto/policytagmanagerserialization.proto",
    package="google.cloud.datacatalog.v1beta1",
    syntax="proto3",
    serialized_options=b'\n$com.google.cloud.datacatalog.v1beta1B"PolicyTagManagerSerializationProtoP\001ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\370\001\001\252\002 Google.Cloud.DataCatalog.V1Beta1\312\002 Google\\Cloud\\DataCatalog\\V1beta1\352\002#Google::Cloud::DataCatalog::V1beta1',
    serialized_pb=b'\nJgoogle/cloud/datacatalog_v1beta1/proto/policytagmanagerserialization.proto\x12 google.cloud.datacatalog.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a=google/cloud/datacatalog_v1beta1/proto/policytagmanager.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a\x17google/api/client.proto"\x90\x01\n\x12SerializedTaxonomy\x12\x19\n\x0c\x64isplay_name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12J\n\x0bpolicy_tags\x18\x03 \x03(\x0b\x32\x35.google.cloud.datacatalog.v1beta1.SerializedPolicyTag"\x97\x01\n\x13SerializedPolicyTag\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12P\n\x11\x63hild_policy_tags\x18\x04 \x03(\x0b\x32\x35.google.cloud.datacatalog.v1beta1.SerializedPolicyTag"\xa9\x01\n\x17ImportTaxonomiesRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\x12#datacatalog.googleapis.com/Taxonomy\x12G\n\rinline_source\x18\x02 \x01(\x0b\x32..google.cloud.datacatalog.v1beta1.InlineSourceH\x00\x42\x08\n\x06source"]\n\x0cInlineSource\x12M\n\ntaxonomies\x18\x01 \x03(\x0b\x32\x34.google.cloud.datacatalog.v1beta1.SerializedTaxonomyB\x03\xe0\x41\x02"Z\n\x18ImportTaxonomiesResponse\x12>\n\ntaxonomies\x18\x01 \x03(\x0b\x32*.google.cloud.datacatalog.v1beta1.Taxonomy"\xc7\x01\n\x17\x45xportTaxonomiesRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\x12#datacatalog.googleapis.com/Taxonomy\x12?\n\ntaxonomies\x18\x02 \x03(\tB+\xe0\x41\x02\xfa\x41%\n#datacatalog.googleapis.com/Taxonomy\x12\x1f\n\x15serialized_taxonomies\x18\x03 \x01(\x08H\x00\x42\r\n\x0b\x64\x65stination"d\n\x18\x45xportTaxonomiesResponse\x12H\n\ntaxonomies\x18\x01 \x03(\x0b\x32\x34.google.cloud.datacatalog.v1beta1.SerializedTaxonomy2\x92\x04\n\x1dPolicyTagManagerSerialization\x12\xd0\x01\n\x10ImportTaxonomies\x12\x39.google.cloud.datacatalog.v1beta1.ImportTaxonomiesRequest\x1a:.google.cloud.datacatalog.v1beta1.ImportTaxonomiesResponse"E\x82\xd3\xe4\x93\x02?":/v1beta1/{parent=projects/*/locations/*}/taxonomies:import:\x01*\x12\xcd\x01\n\x10\x45xportTaxonomies\x12\x39.google.cloud.datacatalog.v1beta1.ExportTaxonomiesRequest\x1a:.google.cloud.datacatalog.v1beta1.ExportTaxonomiesResponse"B\x82\xd3\xe4\x93\x02<\x12:/v1beta1/{parent=projects/*/locations/*}/taxonomies:export\x1aN\xca\x41\x1a\x64\x61tacatalog.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\x88\x02\n$com.google.cloud.datacatalog.v1beta1B"PolicyTagManagerSerializationProtoP\x01ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\xf8\x01\x01\xaa\x02 Google.Cloud.DataCatalog.V1Beta1\xca\x02 Google\\Cloud\\DataCatalog\\V1beta1\xea\x02#Google::Cloud::DataCatalog::V1beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanager__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
    ],
)


_SERIALIZEDTAXONOMY = _descriptor.Descriptor(
    name="SerializedTaxonomy",
    full_name="google.cloud.datacatalog.v1beta1.SerializedTaxonomy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.SerializedTaxonomy.display_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.SerializedTaxonomy.description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="policy_tags",
            full_name="google.cloud.datacatalog.v1beta1.SerializedTaxonomy.policy_tags",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=319,
    serialized_end=463,
)


_SERIALIZEDPOLICYTAG = _descriptor.Descriptor(
    name="SerializedPolicyTag",
    full_name="google.cloud.datacatalog.v1beta1.SerializedPolicyTag",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.SerializedPolicyTag.display_name",
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.SerializedPolicyTag.description",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="child_policy_tags",
            full_name="google.cloud.datacatalog.v1beta1.SerializedPolicyTag.child_policy_tags",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=466,
    serialized_end=617,
)


_IMPORTTAXONOMIESREQUEST = _descriptor.Descriptor(
    name="ImportTaxonomiesRequest",
    full_name="google.cloud.datacatalog.v1beta1.ImportTaxonomiesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ImportTaxonomiesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\022#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="inline_source",
            full_name="google.cloud.datacatalog.v1beta1.ImportTaxonomiesRequest.inline_source",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="source",
            full_name="google.cloud.datacatalog.v1beta1.ImportTaxonomiesRequest.source",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=620,
    serialized_end=789,
)


_INLINESOURCE = _descriptor.Descriptor(
    name="InlineSource",
    full_name="google.cloud.datacatalog.v1beta1.InlineSource",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="taxonomies",
            full_name="google.cloud.datacatalog.v1beta1.InlineSource.taxonomies",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=791,
    serialized_end=884,
)


_IMPORTTAXONOMIESRESPONSE = _descriptor.Descriptor(
    name="ImportTaxonomiesResponse",
    full_name="google.cloud.datacatalog.v1beta1.ImportTaxonomiesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="taxonomies",
            full_name="google.cloud.datacatalog.v1beta1.ImportTaxonomiesResponse.taxonomies",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=886,
    serialized_end=976,
)


_EXPORTTAXONOMIESREQUEST = _descriptor.Descriptor(
    name="ExportTaxonomiesRequest",
    full_name="google.cloud.datacatalog.v1beta1.ExportTaxonomiesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ExportTaxonomiesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\022#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="taxonomies",
            full_name="google.cloud.datacatalog.v1beta1.ExportTaxonomiesRequest.taxonomies",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\n#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="serialized_taxonomies",
            full_name="google.cloud.datacatalog.v1beta1.ExportTaxonomiesRequest.serialized_taxonomies",
            index=2,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.datacatalog.v1beta1.ExportTaxonomiesRequest.destination",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=979,
    serialized_end=1178,
)


_EXPORTTAXONOMIESRESPONSE = _descriptor.Descriptor(
    name="ExportTaxonomiesResponse",
    full_name="google.cloud.datacatalog.v1beta1.ExportTaxonomiesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="taxonomies",
            full_name="google.cloud.datacatalog.v1beta1.ExportTaxonomiesResponse.taxonomies",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1180,
    serialized_end=1280,
)

_SERIALIZEDTAXONOMY.fields_by_name["policy_tags"].message_type = _SERIALIZEDPOLICYTAG
_SERIALIZEDPOLICYTAG.fields_by_name[
    "child_policy_tags"
].message_type = _SERIALIZEDPOLICYTAG
_IMPORTTAXONOMIESREQUEST.fields_by_name["inline_source"].message_type = _INLINESOURCE
_IMPORTTAXONOMIESREQUEST.oneofs_by_name["source"].fields.append(
    _IMPORTTAXONOMIESREQUEST.fields_by_name["inline_source"]
)
_IMPORTTAXONOMIESREQUEST.fields_by_name[
    "inline_source"
].containing_oneof = _IMPORTTAXONOMIESREQUEST.oneofs_by_name["source"]
_INLINESOURCE.fields_by_name["taxonomies"].message_type = _SERIALIZEDTAXONOMY
_IMPORTTAXONOMIESRESPONSE.fields_by_name[
    "taxonomies"
].message_type = (
    google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_policytagmanager__pb2._TAXONOMY
)
_EXPORTTAXONOMIESREQUEST.oneofs_by_name["destination"].fields.append(
    _EXPORTTAXONOMIESREQUEST.fields_by_name["serialized_taxonomies"]
)
_EXPORTTAXONOMIESREQUEST.fields_by_name[
    "serialized_taxonomies"
].containing_oneof = _EXPORTTAXONOMIESREQUEST.oneofs_by_name["destination"]
_EXPORTTAXONOMIESRESPONSE.fields_by_name[
    "taxonomies"
].message_type = _SERIALIZEDTAXONOMY
DESCRIPTOR.message_types_by_name["SerializedTaxonomy"] = _SERIALIZEDTAXONOMY
DESCRIPTOR.message_types_by_name["SerializedPolicyTag"] = _SERIALIZEDPOLICYTAG
DESCRIPTOR.message_types_by_name["ImportTaxonomiesRequest"] = _IMPORTTAXONOMIESREQUEST
DESCRIPTOR.message_types_by_name["InlineSource"] = _INLINESOURCE
DESCRIPTOR.message_types_by_name["ImportTaxonomiesResponse"] = _IMPORTTAXONOMIESRESPONSE
DESCRIPTOR.message_types_by_name["ExportTaxonomiesRequest"] = _EXPORTTAXONOMIESREQUEST
DESCRIPTOR.message_types_by_name["ExportTaxonomiesResponse"] = _EXPORTTAXONOMIESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SerializedTaxonomy = _reflection.GeneratedProtocolMessageType(
    "SerializedTaxonomy",
    (_message.Message,),
    {
        "DESCRIPTOR": _SERIALIZEDTAXONOMY,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanagerserialization_pb2",
        "__doc__": """Message capturing a taxonomy and its policy tag hierarchy
  as a nested proto. Used for taxonomy import/export and mutation.
  
  
  Attributes:
      display_name:
          Required. Display name of the taxonomy. Max 200 bytes when
          encoded in UTF-8.
      description:
          Description of the serialized taxonomy. The length of the
          description is limited to 2000 bytes when encoded in UTF-8. If
          not set, defaults to an empty description.
      policy_tags:
          Top level policy tags associated with the taxonomy if any.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SerializedTaxonomy)
    },
)
_sym_db.RegisterMessage(SerializedTaxonomy)

SerializedPolicyTag = _reflection.GeneratedProtocolMessageType(
    "SerializedPolicyTag",
    (_message.Message,),
    {
        "DESCRIPTOR": _SERIALIZEDPOLICYTAG,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanagerserialization_pb2",
        "__doc__": """Message representing one policy tag when exported as a
  nested proto.
  
  
  Attributes:
      display_name:
          Required. Display name of the policy tag. Max 200 bytes when
          encoded in UTF-8.
      description:
          Description of the serialized policy tag. The length of the
          description is limited to 2000 bytes when encoded in UTF-8. If
          not set, defaults to an empty description.
      child_policy_tags:
          Children of the policy tag if any.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.SerializedPolicyTag)
    },
)
_sym_db.RegisterMessage(SerializedPolicyTag)

ImportTaxonomiesRequest = _reflection.GeneratedProtocolMessageType(
    "ImportTaxonomiesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _IMPORTTAXONOMIESREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanagerserialization_pb2",
        "__doc__": """Request message for
  [ImportTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ImportTaxonomies].
  
  
  Attributes:
      parent:
          Required. Resource name of project that the newly created
          taxonomies will belong to.
      source:
          Required. Source taxonomies to be imported in a tree
          structure.
      inline_source:
          Inline source used for taxonomies import
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ImportTaxonomiesRequest)
    },
)
_sym_db.RegisterMessage(ImportTaxonomiesRequest)

InlineSource = _reflection.GeneratedProtocolMessageType(
    "InlineSource",
    (_message.Message,),
    {
        "DESCRIPTOR": _INLINESOURCE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanagerserialization_pb2",
        "__doc__": """Inline source used for taxonomies import.
  
  
  Attributes:
      taxonomies:
          Required. Taxonomies to be imported.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.InlineSource)
    },
)
_sym_db.RegisterMessage(InlineSource)

ImportTaxonomiesResponse = _reflection.GeneratedProtocolMessageType(
    "ImportTaxonomiesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _IMPORTTAXONOMIESRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanagerserialization_pb2",
        "__doc__": """Response message for
  [ImportTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ImportTaxonomies].
  
  
  Attributes:
      taxonomies:
          Taxonomies that were imported.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ImportTaxonomiesResponse)
    },
)
_sym_db.RegisterMessage(ImportTaxonomiesResponse)

ExportTaxonomiesRequest = _reflection.GeneratedProtocolMessageType(
    "ExportTaxonomiesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTTAXONOMIESREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanagerserialization_pb2",
        "__doc__": """Request message for
  [ExportTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ExportTaxonomies].
  
  
  Attributes:
      parent:
          Required. Resource name of the project that taxonomies to be
          exported will share.
      taxonomies:
          Required. Resource names of the taxonomies to be exported.
      destination:
          Required. Taxonomies export destination.
      serialized_taxonomies:
          Export taxonomies as serialized taxonomies.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ExportTaxonomiesRequest)
    },
)
_sym_db.RegisterMessage(ExportTaxonomiesRequest)

ExportTaxonomiesResponse = _reflection.GeneratedProtocolMessageType(
    "ExportTaxonomiesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXPORTTAXONOMIESRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanagerserialization_pb2",
        "__doc__": """Response message for
  [ExportTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ExportTaxonomies].
  
  
  Attributes:
      taxonomies:
          List of taxonomies and policy tags in a tree structure.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ExportTaxonomiesResponse)
    },
)
_sym_db.RegisterMessage(ExportTaxonomiesResponse)


DESCRIPTOR._options = None
_SERIALIZEDTAXONOMY.fields_by_name["display_name"]._options = None
_SERIALIZEDPOLICYTAG.fields_by_name["display_name"]._options = None
_IMPORTTAXONOMIESREQUEST.fields_by_name["parent"]._options = None
_INLINESOURCE.fields_by_name["taxonomies"]._options = None
_EXPORTTAXONOMIESREQUEST.fields_by_name["parent"]._options = None
_EXPORTTAXONOMIESREQUEST.fields_by_name["taxonomies"]._options = None

_POLICYTAGMANAGERSERIALIZATION = _descriptor.ServiceDescriptor(
    name="PolicyTagManagerSerialization",
    full_name="google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\032datacatalog.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=1283,
    serialized_end=1813,
    methods=[
        _descriptor.MethodDescriptor(
            name="ImportTaxonomies",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ImportTaxonomies",
            index=0,
            containing_service=None,
            input_type=_IMPORTTAXONOMIESREQUEST,
            output_type=_IMPORTTAXONOMIESRESPONSE,
            serialized_options=b'\202\323\344\223\002?":/v1beta1/{parent=projects/*/locations/*}/taxonomies:import:\001*',
        ),
        _descriptor.MethodDescriptor(
            name="ExportTaxonomies",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManagerSerialization.ExportTaxonomies",
            index=1,
            containing_service=None,
            input_type=_EXPORTTAXONOMIESREQUEST,
            output_type=_EXPORTTAXONOMIESRESPONSE,
            serialized_options=b"\202\323\344\223\002<\022:/v1beta1/{parent=projects/*/locations/*}/taxonomies:export",
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_POLICYTAGMANAGERSERIALIZATION)

DESCRIPTOR.services_by_name[
    "PolicyTagManagerSerialization"
] = _POLICYTAGMANAGERSERIALIZATION

# @@protoc_insertion_point(module_scope)
